# Generated by Django 3.2.11 on 2022-01-17 17:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("django_aws_api_gateway_websockets", "0001_initial"),
    ]

    operations = [
        migrations.RenameField(
            model_name="websocketsession",
            old_name="author",
            new_name="user",
        ),
    ]
